RunnableHelper class

Constructors

RunnableHelper({int duration = 3000, int max = 1, bool beforeLoad = false})

Properties

counter → int
no setter
duration ↔ int
latefinal
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
indexingSize → int
no setter
invertedIndex → int
no setter
isCompleted → bool
no setter
max ↔ int
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCompleted() → void
onLoad(int index) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited