RemainingDuration class

Inheritance
Available extensions

Constructors

RemainingDuration({int days = 0, int hours = 0, int minutes = 0, int seconds = 0, int milliseconds = 0, int microseconds = 0})
const
RemainingDuration.from(Duration duration)
factory

Properties

days int

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
hashCode int
The hash code of a duration is the hash code of its inMicroseconds.
no setterinherited
hours int
no setter
hours int

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
hoursAs2D String
no setter
hoursAs2D String

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
inDays int
The number of entire days spanned by this Duration.
no setterinherited
inHours int
The number of entire hours spanned by this Duration.
no setterinherited
inMicroseconds int
The time offset of this duration in microseconds.
finalinherited
inMilliseconds int
The number of whole milliseconds spanned by this Duration.
no setterinherited
inMinutes int
The number of whole minutes spanned by this Duration.
no setterinherited
inSeconds int
The number of whole seconds spanned by this Duration.
no setterinherited
isNegative bool
Whether this Duration is negative.
no setterinherited
isNotValid bool

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
isValid bool

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
microseconds int
no setter
microseconds int

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
milliseconds int
no setter
milliseconds int

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
minutes int
no setter
minutes int

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
minutesAs2D String
no setter
minutesAs2D String

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds int
no setter
seconds int

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
secondsAs2D String
no setter
secondsAs2D String

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
text String
no setter
text String

Available on Duration?, provided by the RemainingDurationHelper extension

no setter
use RemainingDuration

Available on Duration?, provided by the RemainingDurationHelper extension

no setter

Methods

abs() Duration
A positive Duration with the same absolute length as this Duration.
inherited
compareTo(Duration other) int
Compares this Duration to other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([String separator = ":"]) String
A string representation of this Duration.
override
toText([String separator = ":"]) String

Available on Duration?, provided by the RemainingDurationHelper extension

Operators

operator *(num factor) Duration
This Duration scaled by factor.
inherited
operator +(Duration other) Duration
Adds this Duration and other and returns the sum as a new Duration object.
inherited
operator -(Duration other) Duration
The offset of this duration minus the offset of other.
inherited
operator <(Duration other) bool
Whether this duration's offset is smaller than that of other.
inherited
operator <=(Duration other) bool
Whether this duration's offset is not greater than that of other.
inherited
operator ==(Object other) bool
Whether this Duration is equivalent to other.
inherited
operator >(Duration other) bool
Whether this duration's offset is greater than that of other.
inherited
operator >=(Duration other) bool
Whether this duration's offset is not smaller than that of other.
inherited
operator unary-() Duration
Creates a new Duration with the opposite sign of this Duration.
inherited
operator ~/(int quotient) Duration
One-quotientth of this duration.
inherited