ClientLogs class

Properties

client → String
final
hashCode → int
The hash code for this object.
no setterinherited
logs → Map<String, int>
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHits([String? key]) → int
getInitialHits([String? key]) → int
getListeningHits([String? key]) → int
getRequestedHits([String? key]) → int
getResponseHits([String? key]) → int
getTotalHits([String? key]) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited