Internet class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ bool
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify(bool value) → void
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

connected ↔ Future<bool>
Internet.connected = ConnectivityProvider.I.isConnected;
getter/setter pair
connection ↔ Stream<bool>
Internet.connection = ConnectivityProvider.I.connection;
getter/setter pair
i → Internet
no setter
instance → Internet
no setter
isConnected → bool
no setter

Static Methods

init({Future<bool>? connected, Stream<bool>? connection}) → Future<void>
// CONNECTIVITY
setOnChangedListener(ValueChanged<bool> value) → void