KeyGenerator class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

dateKey → String
Generates a unique image key based on the current date and time.
no setter
uniqueKey → String
no setter

Static Methods

countPossibleWords(int length, String chars) → BigInt
generateKey({String? name, int? timeMills, int extraKeySize = 5, KeyFormats format = KeyFormats.numbers}) → String
Generates a key based on the provided name or the current timestamp.
randomKey({int length = 6, String? chars, List<String> ignores = const [], KeyFormats format = KeyFormats.alphabetsAndNumbers}) → String