ListGenerator<T> class

A utility class for creating and managing lists in chunks.

Constructors

ListGenerator(int capacity)
Creates a new instance of ListGenerator with the specified capacity.

Properties

capacity → int
final
collections → List<List<T>>
Gets all the collections (chunks) created by the ListGenerator.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
Gets the current index of the ListGenerator.
no setter
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

chunk([int? position]) → List<T>
Gets the current collection (chunk) from the ListGenerator.
load(Iterable<T> list, [int initialIndex = 0]) → List<List<T>>
Loads a list into the ListGenerator and divides it into chunks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited