ByteUnits enum

Enum representing various byte units and their conversion values.

Inheritance
Available extensions

Values

bytes → const ByteUnits
kb → const ByteUnits
mb → const ByteUnits
gb → const ByteUnits
tb → const ByteUnits
pb → const ByteUnits
eb → const ByteUnits
zb → const ByteUnits
yb → const ByteUnits
auto → const ByteUnits

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → num
Returns the unit value for the byte unit.
no setter
value → double
final

Methods

isSameAs(Object? source) → bool

Available on Enum, provided by the EnumHelper extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(num? value) → Readable
Formats the given value as a Readable instance using the byte unit.
toString() → String
A string representation of this object.
inherited
write(num? value) → double

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → ByteUnits
Returns the ByteUnits instance at the specified index.

Constants

values → const List<ByteUnits>
A constant List of the values in this enum, in order of their declaration.