OrderedListStyle enum

Inheritance
Available extensions

Values

number → const OrderedListStyle
const OrderedListStyle("1", "number")
lowerAlpha → const OrderedListStyle
const OrderedListStyle("a", "lower_alpha")
upperAlpha → const OrderedListStyle
const OrderedListStyle("A", "upper_alpha")
lowerRoman → const OrderedListStyle
const OrderedListStyle("i", "lower_roman")
upperRoman → const OrderedListStyle
const OrderedListStyle("I", "upper_roman")
lowerGreek → const OrderedListStyle
const OrderedListStyle("α", "lower_greek")
upperGreek → const OrderedListStyle
const OrderedListStyle("Α", "upper_greek")

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sign → String
final

Methods

isSameAs(Object? source) → bool

Available on Enum, provided by the EnumHelper extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sequence(int index) → String
Use Case:
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

from(String? style) → OrderedListStyle?

Constants

values → const List<OrderedListStyle>
A constant List of the values in this enum, in order of their declaration.