Pagination class

Utility class for handling pagination in a ListView.

Constructors

Pagination({required ScrollController controller, required OnLoad onLoad, required OnLoading onLoading, double preload = 1000})
Constructor for Pagination.

Properties

controller → ScrollController
final
hashCode → int
The hash code for this object.
no setterinherited
onLoad → OnLoad
final
onLoading → OnLoading
final
preload → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited