PaginationController class

Extension of ScrollController with additional pagination functionality.

Inheritance
Available extensions

Constructors

PaginationController()

Properties

debugLabel → String?
A label that is used in the toString output. Intended to aid with identifying scroll controller instances in debug output.
finalinherited
hasClients → bool
Whether any ScrollPosition objects have attached themselves to the ScrollController using the attach method.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
initialScrollOffset → double
The initial value to use for offset.
no setterinherited
keepScrollOffset → bool
Each time a scroll completes, save the current scroll offset with PageStorage and restore it if this controller's scrollable is recreated.
finalinherited
offset → double
The current scroll offset of the scrollable widget.
no setterinherited
onAttach → ScrollControllerCallback?
Called when a ScrollPosition is attached to the scroll controller.
finalinherited
onDetach → ScrollControllerCallback?
Called when a ScrollPosition is detached from the scroll controller.
finalinherited
position → ScrollPosition
Returns the attached ScrollPosition, from which the actual scroll offset of the ScrollView can be obtained.
no setterinherited
positions → Iterable<ScrollPosition>
The currently attached positions.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateTo(double offset, {required Duration duration, required Curve curve}) → Future<void>
Animates the position from its current value to the given value.
inherited
attach(ScrollPosition position) → void
Register the given position with this controller.
inherited
createScrollPosition(ScrollPhysics physics, ScrollContext context, ScrollPosition? oldPosition) → ScrollPosition
Creates a ScrollPosition for use by a Scrollable widget.
inherited
debugFillDescription(List<String> description) → void
Add additional information to the given description for use by toString.
inherited
detach(ScrollPosition position) → void
Unregister the given position with this controller.
inherited
dispose() → void
Discards any resources used by the object.
inherited
jumpTo(double value) → void
Jumps the scroll position from its current value to the given value, without animation, and without checking if the new value is in range.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
paginate({double preload = 1000, required OnLoad onLoad, required OnLoading onLoading}) → void
Method to enable pagination for the associated ListView.
paging({required OnPagingListener onListen}) → ScrollController

Available on ScrollController, provided by the ScrollControllerExtension extension

removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited