PathReplacer class

Utility class for replacing placeholders in a path with provided values.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

replace(String path, Map<String, String> params) → String
Replaces placeholders in the given path using the provided params map.
replaceByIterable(String path, Iterable<String> params) → String
Replaces placeholders in the given path using values from the params iterable.