Realtime class

Constructors

Realtime({bool future = false, int second = 0, int minute = 0, int hour = 0, int day = 0, int week = 0, int month = 0, int year = 0, Duration diff = Duration.zero, DateTime? dateTime})
const
Realtime.parse(DateTime dateTime)
factory

Properties

dateTime → DateTime
no setter
day → int
final
diff → Duration
final
future → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hour → int
final
minute → int
final
month → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
final
week → int
final
year → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

date ↔ String Function(DateTime date)?
getter/setter pair
formats ↔ RealtimeTextFormats
getter/setter pair
options ↔ RealtimeOptions
getter/setter pair
time ↔ String Function(DateTime date)?
getter/setter pair

Static Methods

format(DateTime dateTime, {RealtimeTextFormats? formats, RealtimeOptions? options, String separator = " at ", String time(DateTime date)?, String date(DateTime date)?}) → String