RealtimeOptions class

Constructors

RealtimeOptions({bool after = true, bool ago = true, bool now = true, int nowShowingBeforeSeconds = 10, bool today = false, bool tomorrow = true, bool yesterday = true, bool second = true, bool minute = true, bool hour = true, bool day = true, bool week = false, bool month = false, bool year = false, String onYears(Realtime time)?, String onMonths(Realtime time)?, String onWeeks(Realtime time)?, String onDays(Realtime time)?, String onHours(Realtime time)?, String onMinutes(Realtime time)?, String onSeconds(Realtime time)?, String onTomorrow(Realtime time)?, String onToday(Realtime time)?, String onYesterday(Realtime time)?})
const

Properties

after → bool
final
ago → bool
final
day → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hour → bool
final
minute → bool
final
month → bool
final
now → bool
final
nowShowingBeforeSeconds → int
final
onDays → String Function(Realtime time)?
final
onHours → String Function(Realtime time)?
final
onMinutes → String Function(Realtime time)?
final
onMonths → String Function(Realtime time)?
final
onSeconds → String Function(Realtime time)?
final
onToday → String Function(Realtime time)?
final
onTomorrow → String Function(Realtime time)?
final
onWeeks → String Function(Realtime time)?
final
onYears → String Function(Realtime time)?
final
onYesterday → String Function(Realtime time)?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → bool
final
today → bool
final
tomorrow → bool
final
week → bool
final
year → bool
final
yesterday → bool
final

Methods

merge(RealtimeOptions? other) → RealtimeOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited