RealtimeTextFormats class

Constructors

RealtimeTextFormats({String after = "after", String ago = "ago", String now = "now", String today = "Today", String tomorrow = "Tomorrow", String yesterday = "Yesterday", TextFormat second = const TextFormat(singular: "second", plural: "seconds"), TextFormat minute = const TextFormat(singular: "minute", plural: "minutes"), TextFormat hour = const TextFormat(singular: "hour", plural: "hours"), TextFormat day = const TextFormat(singular: "day", plural: "days"), TextFormat week = const TextFormat(singular: "week", plural: "weeks"), TextFormat month = const TextFormat(singular: "month", plural: "months"), TextFormat year = const TextFormat(singular: "year", plural: "years")})
const

Properties

after → String
final
ago → String
final
day → TextFormat
final
hashCode → int
The hash code for this object.
no setterinherited
hour → TextFormat
final
minute → TextFormat
final
month → TextFormat
final
now → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → TextFormat
final
today → String
final
tomorrow → String
final
week → TextFormat
final
year → TextFormat
final
yesterday → String
final

Methods

merge(RealtimeTextFormats? other) → RealtimeTextFormats
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited