RouteManager class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

allowFilter ← bool
no getter
allowMultiple ← bool
no getter
currentRoute → String?
no setter
ignorableRoutes ← Iterable<String>
no getter
initialRoute → String?
no setter
initialRoutes ← String
no getter
previousRoute → String?
no setter
routes → String
no setter
separator ← String
no getter
supportedRoutes ← Iterable<String>
no getter

Static Methods

clear([String? route]) → void
isIgnorableRoute(String? route) → bool
isSupportedRoute(String? route) → bool
listen(ValueChanged<String> listener) → void
pop([String? route]) → void
push(String? route) → void
replace(String? route, String? previousRoute) → void