Validator class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

equals(Object? value, Object? compareValue) → bool
isChecked(Object? checker, List? list) → bool
isDigit(String? value) → bool
isInstance<T>(Object? value, T instance) → bool
isLetter(String? value) → bool
isMatched(Object? matcher, Object? value) → bool
isMatchedList(List<String>? matchers, List<String>? values) → bool
isNumeric(String? value) → bool
isRank(double rating, double min) → bool
isValidDay(Object? day) → bool
isValidDigit(String? value) → bool
isValidDigitWithLetter(String? value) → bool
isValidDigitWithPlus(String? value) → bool
isValidEmail(String? email, [RegExp? pattern]) → bool
isValidLetter(String? value) → bool
isValidList(List? list) → bool
isValidMonth(Object? month) → bool
isValidObject(Object? value) → bool
isValidPassword(String? password, {int minLength = 6, int maxLength = 20, RegExp? pattern}) → bool
isValidPath(String? path, [RegExp? pattern]) → bool
isValidPhone(String? phone, [RegExp? pattern]) → bool
isValidRetypePassword(String? password, String? retypePassword) → bool
isValidSet(Set? list) → bool
isValidString(String? value, {int maxLength = 0, int minLength = 0, RegExp? pattern}) → bool
isValidStrings(List<String> values, {int maxLength = 0, int minLength = 0, RegExp? regs}) → bool
isValidUsername(String? username, {bool withDot = true, RegExp? pattern}) → bool
isValidWebURL(String? url) → bool
isValidYear(Object? year, int requireAge) → bool